Skip to contents

Flatten chains in the results of running monty_sample(), wherein pars, density and typically objects in observations will have the last two dimensions representing 'samples' and 'chains'. Flattening the chains results in the chains dimension being collapsed into the samples dimension.

Usage

monty_flatten_chains(samples)

Arguments

samples

A monty_samples object, from running monty_sample()

Value

A monty_samples object with the chains dimension collapsed into the samples dimension.